@@ -411,6 +411,77 @@ class objearth():
         nc4 = colors.LinearSegmentedColormap('leafwood',segmentdata=cdict)
         return nc4
 
+    @staticmethod
+    def sweetrose():
+        RGB1  = (1., 1., 1.)                            # rgba(254,254,254,255)
+        RGB2  = (0.98823529, 0.88627451, 0.98823529)    # rgba(254,225,253,255)
+        RGB3  = (0.98823529, 0.79215686, 0.99607843)    # rgba(252,202,254,255)
+        RGB4  = (0.98823529, 0.79215686, 0.99607843)    # rgba(248,129,255,255)
+        RGB5  = (0.96470588, 0.02352941, 1.        )    # rgba(235,14,243,255)
+        RGB6  = (0.96470588, 0.01960784, 0.40784314)    # rgba(244,6,102,255)
+        RGB8  = (0.96078431, 0.01960784, 0.        )    # rgba(251,2,0,255)
+        RGB7  = (0.98431373, 0.35294118, 0.03529412)    # rgba(244,90,0,255)
+        RGB9  = (0.98039216, 0.6745098 , 0.00392157)    # rgba(250,169,6,255)
+        RGB10 = (0.96862745, 0.8       , 0.01176471)    # rgba(242,204,16,255)
+        RGB11 = (0.99607843, 0.99215686, 0.01568627)    # rgba(255,253,8,255)
+        RGB12 = (0.02745098, 0.58431373, 0.18039216)    # rgba(3,150,51,255)
+        RGB13 = (0.02352941, 0.6627451 , 0.03137255)    # rgba(7,170,2,255)
+        RGB14 = (0.04705882, 0.98039216, 0.02352941)    # rgba(12,250,4,255)
+        RGB15 = (0.03921569, 0.97647059, 0.50980392)    # rgba(8,250,130,255)
+
+        cdict = {
+            'red':  ((1  / 14 * 0,  (RGB1[0])  ,(RGB1[0])),
+                    (1  / 14 * 1,  (RGB2[0])  ,(RGB2[0])),
+                    (1  / 14 * 2,  (RGB3[0])  ,(RGB3[0])),
+                    (1  / 14 * 3,  (RGB4[0])  ,(RGB4[0])),
+                    (1  / 14 * 4,  (RGB5[0])  ,(RGB5[0])),
+                    (1  / 14 * 5,  (RGB6[0])  ,(RGB6[0])),
+                    (1  / 14 * 6,  (RGB7[0])  ,(RGB7[0])),
+                    (1  / 14 * 7,  (RGB8[0])  ,(RGB8[0])),
+                    (1  / 14 * 8,  (RGB9[0])  ,(RGB9[0])),
+                    (1  / 14 * 9,  (RGB10[0])  ,(RGB10[0])),
+                    (1  / 14 * 10, (RGB11[0])  ,(RGB11[0])),
+                    (1  / 14 * 11, (RGB12[0])  ,(RGB12[0])),
+                    (1  / 14 * 12, (RGB13[0])  ,(RGB13[0])),
+                    (1  / 14 * 13, (RGB14[0])  ,(RGB14[0])),
+                    (1  / 14 * 14, (RGB15[0])  ,(RGB15[0]))),
+
+            'green':((1  / 14 * 0,  (RGB1[1])  ,(RGB1[1])),
+                    (1  / 14 * 1,  (RGB2[1])  ,(RGB2[1])),
+                    (1  / 14 * 2,  (RGB3[1])  ,(RGB3[1])),
+                    (1  / 14 * 3,  (RGB4[1])  ,(RGB4[1])),
+                    (1  / 14 * 4,  (RGB5[1])  ,(RGB5[1])),
+                    (1  / 14 * 5,  (RGB6[1])  ,(RGB6[1])),
+                    (1  / 14 * 6,  (RGB7[1])  ,(RGB7[1])),
+                    (1  / 14 * 7,  (RGB8[1])  ,(RGB8[1])),
+                    (1  / 14 * 8,  (RGB9[1])  ,(RGB9[1])),
+                    (1  / 14 * 9,  (RGB10[1])  ,(RGB10[1])),
+                    (1  / 14 * 10, (RGB11[1])  ,(RGB11[1])),
+                    (1  / 14 * 11, (RGB12[1])  ,(RGB12[1])),
+                    (1  / 14 * 12, (RGB13[1])  ,(RGB13[1])),
+                    (1  / 14 * 13, (RGB14[1])  ,(RGB14[1])),
+                    (1  / 14 * 14, (RGB15[1])  ,(RGB15[1]))),
+
+            'blue': ((1  / 14 * 0,  (RGB1[2])  ,(RGB1[2])),
+                    (1  / 14 * 1,  (RGB2[2])  ,(RGB2[2])),
+                    (1  / 14 * 2,  (RGB3[2])  ,(RGB3[2])),
+                    (1  / 14 * 3,  (RGB4[2])  ,(RGB4[2])),
+                    (1  / 14 * 4,  (RGB5[2])  ,(RGB5[2])),
+                    (1  / 14 * 5,  (RGB6[2])  ,(RGB6[2])),
+                    (1  / 14 * 6,  (RGB7[2])  ,(RGB7[2])),
+                    (1  / 14 * 7,  (RGB8[2])  ,(RGB8[2])),
+                    (1  / 14 * 8,  (RGB9[2])  ,(RGB9[2])),
+                    (1  / 14 * 9,  (RGB10[2])  ,(RGB10[2])),
+                    (1  / 14 * 10, (RGB11[2])  ,(RGB11[2])),
+                    (1  / 14 * 11, (RGB12[2])  ,(RGB12[2])),
+                    (1  / 14 * 12, (RGB13[2])  ,(RGB13[2])),
+                    (1  / 14 * 13, (RGB14[2])  ,(RGB14[2])),
+                    (1  / 14 * 14, (RGB15[2])  ,(RGB15[2])),
+            )
+        }
+        nc5 = colors.LinearSegmentedColormap('new_cmap',segmentdata=cdict)
+        nc5
+
 
 
 from sklearn.preprocessing import MinMaxScaler, RobustScaler
